"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Delete = void 0;
const command_1 = require("@oclif/command");
const axios_1 = require("axios");
const chalk = require("chalk");
const pingServer_1 = require("../utils/pingServer");
const TokenConfig_1 = require("../utils/TokenConfig");
const { api } = require("../../package.json");
class Delete extends command_1.default {
    async init() {
        if (!(await pingServer_1.default())) {
            this.warn("We are having some server issues! Just hold on!");
            process.exit(0);
        }
    }
    async run() {
        try {
            const { args } = this.parse(Delete);
            const id = args.id;
            if (id == null) {
                this.warn("Please provide an ID in argument!");
            }
            else {
                new TokenConfig_1.default()
                    .getToken(this.config.windows)
                    .then(async (token) => {
                    if (token == null) {
                        this.warn("You are not authorized to use this command!\n" +
                            chalk.green("Use $ note login to authorize"));
                    }
                    else {
                        try {
                            const response = await axios_1.default.delete(`${api}/note/${id}`, {
                                headers: { Authorization: `Bearer ${token}` },
                            });
                            // deleted
                            this.log(chalk.green("Sad to see you deleting your Note :(\n"));
                            this.log("But nevermind, note-taking is a good habit! Don’t leave that...");
                        }
                        catch (error) {
                            if (error.response == undefined) {
                                this.warn("We are having some server issues! Just hold on!");
                                process.exit(0);
                            }
                            if (error.response.data.idError) {
                                this.warn("Couldn't find your note! Provide a valid ID.");
                                process.exit(0);
                            }
                            if (error.response.data.noteError) {
                                this.warn("Failed to parse your note.");
                                process.exit(0);
                            }
                        }
                    }
                })
                    .catch((error) => {
                    this.log(error);
                });
            }
        }
        catch (error) {
            this.log(error);
        }
    }
}
exports.Delete = Delete;
Delete.description = `delete your note(s)
You can delete some specific notes if you think they are not worthy.`;
Delete.usage = ["delete <ID>"];
Delete.args = [{ name: "id" }];
Delete.examples = ["$ noteli delete 2"];
