"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Login = void 0;
const command_1 = require("@oclif/command");
const chalk = require("chalk");
const inquirer = require("inquirer");
const axios_1 = require("axios");
const express = require("express");
const open = require("open");
const TokenConfig_1 = require("../utils/TokenConfig");
const pingServer_1 = require("../utils/pingServer");
const tokenConfig = new TokenConfig_1.default();
const { api } = require("../../package.json");
class Login extends command_1.default {
    async init() {
        if (!(await pingServer_1.default())) {
            this.warn("We are having some server issues! Just hold on!");
            process.exit(0);
        }
    }
    async authorize() {
        inquirer
            .prompt({
            name: "authorize",
            type: "confirm",
            message: "Would you like us to open browser to login?",
            default: true,
        })
            .then(async (answer) => {
            if (answer.authorize) {
                // open browser and authorize!
                try {
                    const app = express();
                    app.use(express.json());
                    app.use(express.urlencoded({ extended: false }));
                    const server = app.listen(9991);
                    let resolve;
                    const p = new Promise((_resolve) => {
                        resolve = _resolve;
                    });
                    const authAPI = await axios_1.default.post(`${api}/authorize`);
                    app.get("/callback", (req, res) => {
                        resolve(req.query.code);
                        res.redirect("https://noteli.tech/done");
                    });
                    const authUrl = authAPI.data["url"];
                    open(authUrl);
                    // Wait for the first auth code
                    const code = await p;
                    const response = await axios_1.default.post(`${api}/token`, { code });
                    const access_token = response.data.token;
                    const user = await tokenConfig.getUser(access_token);
                    await tokenConfig.setToken(access_token, this.config.windows);
                    server.close();
                    this.log("\nLogged in successfully as " + chalk.greenBright(user.email));
                    this.exit(0);
                }
                catch (error) {
                    this.log(error.response);
                }
            }
            else {
                this.log(chalk.yellow("\nIf you're not authorized,\nYou won't be able to use Noteli."));
            }
        })
            .catch((err) => this.log(err));
    }
    async run() {
        tokenConfig
            .getToken(this.config.windows)
            .then(async (token) => {
            if (token == "") {
                await this.authorize();
            }
            else {
                tokenConfig
                    .getUser(token)
                    .then(async (user) => {
                    if (user != null) {
                        this.log(chalk.yellow("\nAn account already exists!"));
                        this.log("Logged in as " + chalk.greenBright(user.email));
                    }
                    else {
                        await this.authorize();
                    }
                })
                    .catch(async (err) => {
                    await this.authorize();
                });
            }
        })
            .catch(async (err) => {
            await this.authorize();
        });
    }
}
exports.Login = Login;
Login.description = `login the user for noteli
Uses Auth0 Social Login to authorize user using browser.`;
