"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Read = void 0;
const command_1 = require("@oclif/command");
const axios_1 = require("axios");
const chalk = require("chalk");
const cli_ux_1 = require("cli-ux");
const pingServer_1 = require("../utils/pingServer");
const TokenConfig_1 = require("../utils/TokenConfig");
const { api } = require("../../package.json");
class Read extends command_1.default {
    constructor() {
        super(...arguments);
        this.readAllNotes = async () => {
            try {
                new TokenConfig_1.default()
                    .getToken(this.config.windows)
                    .then(async (token) => {
                    if (token == null) {
                        this.warn("You are not authorized to use this command!\n" +
                            chalk.green("Use $ note login to authorize"));
                    }
                    else {
                        try {
                            cli_ux_1.default.action.start(chalk.blueBright("Fetching your notes"));
                            const response = await axios_1.default.get(`${api}/notes`, {
                                headers: { Authorization: `Bearer ${token}` },
                            });
                            cli_ux_1.default.action.stop("\n");
                            let note;
                            this.log(chalk.bold(chalk.blueBright("ID\tNote Title")));
                            for (let i = 0; i < response.data.data.length; i++) {
                                note = response.data.data[i];
                                this.log(chalk.greenBright("#" + note.noteId + "\t" + note.title));
                            }
                            this.log(`\nTo grab specific note, just run\n${chalk.green("$ noteli read <ID>")}`);
                        }
                        catch (error) {
                            if (error.response.data.notesError) {
                                cli_ux_1.default.action.stop(chalk.yellow("\n\nYou haven't created any notes!"));
                                this.log(`Use ${chalk.greenBright("$ noteli create")} to create your first note!`);
                            }
                            if (error.response.data.authError) {
                                cli_ux_1.default.action.stop(chalk.yellow("\n\nYou aren't authorized!"));
                                this.log(`Use ${chalk.greenBright("$ noteli login")} to login!`);
                            }
                        }
                    }
                })
                    .catch((err) => {
                    this.log(err);
                });
            }
            catch (error) {
                this.log(error);
            }
        };
        this.readNote = async (id) => {
            try {
                new TokenConfig_1.default()
                    .getToken(this.config.windows)
                    .then(async (token) => {
                    if (token == null) {
                        this.warn("You are not authorized to use this command!\n" +
                            chalk.green("Use $ note login to authorize"));
                    }
                    else {
                        try {
                            const response = await axios_1.default.get(`${api}/note/${id}`, {
                                headers: { Authorization: `Bearer ${token}` },
                            });
                            const note = response.data.data;
                            this.log(chalk.bold(`${chalk.yellow(`#${id} - `)}${chalk.green(note.title)}\n`));
                            this.log(chalk.bold(`${chalk.green(`${note.content}`)}`));
                        }
                        catch (error) {
                            if (error.response == undefined) {
                                this.warn("We are having some server issues! Just hold on!");
                                process.exit(0);
                            }
                            if (error.response.data.authError) {
                                this.warn("You are not authenticated!");
                                process.exit(0);
                            }
                            if (error.response.data.idError) {
                                this.warn("You have provided wrong ID!");
                                process.exit(0);
                            }
                            if (error.response.data.parseError) {
                                this.warn("Please provide a valid ID!");
                                process.exit(0);
                            }
                        }
                    }
                })
                    .catch((error) => {
                    this.log(error);
                });
            }
            catch (error) {
                this.log(error);
            }
        };
    }
    async init() {
        if (!(await pingServer_1.default())) {
            this.warn("We are having some server issues! Just hold on!");
            this.exit(0);
        }
    }
    async run() {
        let ops = "all";
        try {
            const { args } = this.parse(Read);
            if (args.id != null) {
                ops = args.id;
            }
            if (ops == "all") {
                await this.readAllNotes();
            }
            else {
                await this.readNote(parseInt(args.id));
            }
        }
        catch (error) {
            this.log(error);
        }
    }
}
exports.Read = Read;
Read.description = `read all your notes
You can read all your notes or some specific note too.`;
Read.usage = ["read", "read <ID>"];
Read.args = [{ name: "id" }];
Read.examples = ["$ noteli read", "$ noteli read 2"];
