"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const chalk = require("chalk");
const os = require("os");
const axios_1 = require("axios");
const { api } = require("../../package.json");
class TokenConfig {
    async setToken(token, isWindows) {
        if (isWindows) {
            try {
                const tokenLoc = path.join(os.homedir(), "\\.noteli");
                if (await this.checkFile(tokenLoc)) {
                    // file exists, now set the token!
                    fs.writeFileSync(tokenLoc, `${token}`);
                    console.log(chalk.greenBright("\nToken added successfully!"));
                }
                else {
                    // create file and set the token!
                    fs.writeFileSync(tokenLoc, `${token}`);
                    console.log(chalk.greenBright("\nToken added successfully!"));
                }
            }
            catch (error) {
                console.log(chalk.redBright(error));
            }
        }
        else {
            try {
                const tokenLoc = path.join(os.homedir(), "/.noteli");
                if (await this.checkFile(tokenLoc)) {
                    // file exists, now set the token!
                    fs.writeFileSync(tokenLoc, `${token}`);
                    console.log(chalk.greenBright("\nToken added successfully!"));
                }
                else {
                    // create file and set the token!
                    fs.writeFileSync(tokenLoc, `${token}`);
                    console.log(chalk.greenBright("\nToken added successfully!"));
                }
            }
            catch (error) {
                console.log(chalk.redBright(error));
            }
        }
    }
    async revokeToken(isWindows) {
        if (isWindows) {
            try {
                const tokenLoc = path.join(os.homedir(), "\\.noteli");
                if (await this.checkFile(tokenLoc)) {
                    fs.unlink(tokenLoc, (err) => {
                        if (err) {
                            console.log(chalk.redBright("\nFailed to log out!"));
                        }
                        else {
                            console.log(chalk.greenBright("\nSuccessfully logged out!"));
                        }
                    });
                }
                else {
                    console.log(chalk.greenBright("\nSuccessfully logged out!"));
                }
            }
            catch (error) {
                console.log(chalk.redBright(error));
            }
        }
        else {
            try {
                const tokenLoc = path.join(os.homedir(), "/.noteli");
                if (await this.checkFile(tokenLoc)) {
                    fs.unlink(tokenLoc, (err) => {
                        if (err) {
                            console.log(chalk.redBright("\nFailed to log out!"));
                        }
                        else {
                            console.log(chalk.greenBright("\nSuccessfully logged out!"));
                        }
                    });
                }
                else {
                    console.log(chalk.greenBright("\nSuccessfully logged out!"));
                }
            }
            catch (error) {
                console.log(chalk.redBright(error));
            }
        }
    }
    async getToken(isWindows) {
        if (isWindows) {
            try {
                const tokenLoc = path.join(os.homedir(), "\\.noteli");
                const token = fs.readFileSync(tokenLoc, { encoding: "utf-8" });
                return token;
            }
            catch (error) {
                return null;
            }
        }
        else {
            try {
                const tokenLoc = path.join(os.homedir(), "/.noteli");
                const token = fs.readFileSync(tokenLoc, { encoding: "utf-8" });
                return token;
            }
            catch (error) {
                return error;
            }
        }
    }
    async getUser(token) {
        try {
            const response = await axios_1.default.post(`${api}/user`, {}, {
                headers: {
                    Authorization: `Bearer ${token}`,
                },
            });
            return response.data;
        }
        catch (error) {
            return null;
        }
    }
    async checkFile(file) {
        try {
            fs.accessSync(file);
            return true;
        }
        catch (error) {
            return false;
        }
    }
}
exports.default = TokenConfig;
